================
Related projects
================

This is a non-exhaustive list of related, open-source projects that users of orix might
find useful:

- `pyxem <https://github.com/pyxem/pyxem>`_: Python library for multi-dimensional
  diffraction microscopy.
- `diffsims <https://diffsims.rtfd.io>`_: Python library for simulating diffraction.
- `kikuchipy <https://kikuchipy.org>`_: Python library for processing and analysis of
  electron backscatter diffraction (EBSD) patterns.
- `MTEX <https://mtex-toolbox.github.io>`_: Matlab toolbox for analyzing and
  modelling crystallographic textures by means of EBSD or pole figure data.
- `DefDAP <https://defdap.readthedocs.io/en/latest/?badge=latest>`_: Python package for
  correlating EBSD and high-resolution digital image correlation data.
- `quaternion <https://github.com/moble/quaternion>`_: Python package that adds a built
  in quaternion data dtype to NumPy.
- `texture <https://github.com/usnistgov/texture>`_: Python scripts for analysis of
  crystallographic texture.
- `pymicro <https://github.com/heprom/pymicro/>`_: Python package to work with material
  microstructures and 3D data sets.
